;; Generated package description from with-editor.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "with-editor" "3.4.9.0.20260417.5154" "Use the Emacsclient as $EDITOR" '((emacs "26.1") (compat "30.1")) :commit "d0935036eb894680d8ca1a4d1ed8e8d5d90005e5" :authors '(("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev")) :maintainer '("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev") :keywords '("processes" "terminals") :url "https://github.com/magit/with-editor")
